# Copyright 2021 John Reese
# Licensed under the MIT license

"""
Run things on paths
"""

__author__ = "John Reese"
from .__version__ import __version__
from .core import gitignore, project_root, run, walk, walk_and_run, Trailrunner
